@@ -5,16 +5,18 @@ use std::task::{Context, Poll};
 use futures_util::future::poll_fn;
 
 use crate::driver::Driver;
-use crate::local_executor;
+use crate::local_executor::LocalExecutor;
 use crate::waker_fn::waker_fn;
 
 pub struct Runtime {
+    local_executor: LocalExecutor,
     driver: Driver,
 }
 
 impl Runtime {
     pub fn new() -> io::Result<Runtime> {
         Ok(Runtime {
+            local_executor: LocalExecutor::new(),
             driver: Driver::new()?,
         })
     }
@@ -25,15 +27,17 @@ impl Runtime {
     {
         pin_mut!(future);
         self.driver.with(|| {
-            block_on(poll_fn(|cx| loop {
-                if let Poll::Ready(output) = future.as_mut().poll(cx) {
-                    return Poll::Ready(output);
-                }
-                if local_executor::tick() {
-                    return Poll::Pending;
-                }
-                self.driver.wait().expect("driver wait error");
-            }))
+            self.local_executor.with(|| {
+                block_on(poll_fn(|cx| loop {
+                    if let Poll::Ready(output) = future.as_mut().poll(cx) {
+                        return Poll::Ready(output);
+                    }
+                    if self.local_executor.tick() {
+                        return Poll::Pending;
+                    }
+                    self.driver.wait().expect("driver wait error");
+                }))
+            })
         })
     }
 }
